@@ -70,7 +70,7 @@ impl AsyncCommitFiles {
 
 	///
 	pub fn current(
-		&mut self,
+		&self,
 	) -> Result<Option<(CommitFilesParams, ResultType)>> {
 		let c = self.current.lock()?;
 
@@ -84,7 +84,7 @@ impl AsyncCommitFiles {
 	}
 
 	///
-	pub fn fetch(&mut self, params: CommitFilesParams) -> Result<()> {
+	pub fn fetch(&self, params: CommitFilesParams) -> Result<()> {
 		if self.is_pending() {
 			return Ok(());
 		}
