@@ -93,6 +93,24 @@ pub enum Error {
 	#[error("sign error: {0}")]
 	Sign(#[from] crate::sync::sign::SignError),
 
+	///
+	#[error("gix::discover error: {0}")]
+	GixDiscover(#[from] Box<gix::discover::Error>),
+
+	///
+	#[error("gix::reference::find::existing error: {0}")]
+	GixReferenceFindExisting(
+		#[from] gix::reference::find::existing::Error,
+	),
+
+	///
+	#[error("gix::head::peel::to_commit error: {0}")]
+	GixHeadPeelToCommit(#[from] gix::head::peel::to_commit::Error),
+
+	///
+	#[error("gix::revision::walk error: {0}")]
+	GixRevisionWalk(#[from] gix::revision::walk::Error),
+
 	///
 	#[error("amend error: config commit.gpgsign=true detected.\ngpg signing is not supported for amending non-last commits")]
 	SignAmendNonLastCommit,
@@ -120,3 +138,9 @@ impl<T> From<crossbeam_channel::SendError<T>> for Error {
 		Self::Generic(format!("send error: {error}"))
 	}
 }
+
+impl From<gix::discover::Error> for Error {
+	fn from(error: gix::discover::Error) -> Self {
+		Self::GixDiscover(Box::new(error))
+	}
+}
