@@ -69,7 +69,7 @@ impl AsyncPushTags {
 	}
 
 	///
-	pub fn request(&mut self, params: PushTagsRequest) -> Result<()> {
+	pub fn request(&self, params: PushTagsRequest) -> Result<()> {
 		log::trace!("request");
 
 		if self.is_pending()? {
@@ -145,7 +145,7 @@ impl AsyncPushTags {
 		let mut last_res = arc_result.lock()?;
 
 		*last_res = match res {
-			Ok(_) => None,
+			Ok(()) => None,
 			Err(e) => {
 				log::error!("push error: {}", e);
 				Some(e.to_string())
