@@ -82,8 +82,6 @@ pub struct CommitDetails {
 
 impl CommitDetails {
 	///
-	#[allow(clippy::missing_const_for_fn)]
-	// clippy doesn't realise indexing a String is not const
 	pub fn short_hash(&self) -> &str {
 		&self.hash[0..7]
 	}
@@ -148,14 +146,12 @@ mod tests {
 
 		let res = get_commit_details(repo_path, id).unwrap();
 
-		assert_eq!(
-			res.message
-				.as_ref()
-				.unwrap()
-				.subject
-				.starts_with("test msg"),
-			true
-		);
+		assert!(res
+			.message
+			.as_ref()
+			.unwrap()
+			.subject
+			.starts_with("test msg"));
 
 		Ok(())
 	}
