@@ -33,6 +33,7 @@ pub fn diff_contains_file(file_path: String) -> SharedCommitFilterFn {
 
 bitflags! {
 	///
+	#[derive(Debug, Clone, Copy)]
 	pub struct SearchFields: u32 {
 		///
 		const MESSAGE_SUMMARY = 1 << 0;
@@ -59,6 +60,7 @@ impl Default for SearchFields {
 
 bitflags! {
 	///
+	#[derive(Debug, Clone, Copy)]
 	pub struct SearchOptions: u32 {
 		///
 		const CASE_SENSITIVE = 1 << 0;
@@ -113,8 +115,7 @@ impl LogFilterSearch {
 				.new_file()
 				.path()
 				.and_then(|file| file.as_os_str().to_str())
-				.map(|file| self.match_text(file))
-				.unwrap_or_default()
+				.is_some_and(|file| self.match_text(file))
 			{
 				return true;
 			}
@@ -123,8 +124,7 @@ impl LogFilterSearch {
 				.old_file()
 				.path()
 				.and_then(|file| file.as_os_str().to_str())
-				.map(|file| self.match_text(file))
-				.unwrap_or_default()
+				.is_some_and(|file| self.match_text(file))
 		})
 	}
 
@@ -192,8 +192,7 @@ pub fn filter_commit_by_search(
 					.ok()
 				})
 				.flatten()
-				.map(|diff| filter.match_diff(&diff))
-				.unwrap_or_default();
+				.is_some_and(|diff| filter.match_diff(&diff));
 
 			let authors_match = filter
 				.options
@@ -203,13 +202,11 @@ pub fn filter_commit_by_search(
 					let name_match = commit
 						.author()
 						.name()
-						.map(|name| filter.match_text(name))
-						.unwrap_or_default();
+						.is_some_and(|name| filter.match_text(name));
 					let mail_match = commit
 						.author()
 						.email()
-						.map(|name| filter.match_text(name))
-						.unwrap_or_default();
+						.is_some_and(|name| filter.match_text(name));
 
 					name_match || mail_match
 				})
@@ -217,7 +214,8 @@ pub fn filter_commit_by_search(
 
 			Ok(msg_summary_match
 				|| msg_body_match
-				|| file_match || authors_match)
+				|| file_match
+				|| authors_match)
 		},
 	))
 }
