@@ -71,7 +71,7 @@ pub use hooks::{
 };
 pub use hunks::{reset_hunk, stage_hunk, unstage_hunk};
 pub use ignore::add_to_ignore;
-pub use logwalker::LogWalker;
+pub use logwalker::{LogWalker, LogWalkerWithoutFilter};
 pub use merge::{
 	abort_pending_rebase, abort_pending_state,
 	continue_pending_rebase, merge_branch, merge_commit, merge_msg,
@@ -79,9 +79,10 @@ pub use merge::{
 };
 pub use rebase::rebase_branch;
 pub use remotes::{
-	get_default_remote, get_default_remote_for_fetch,
-	get_default_remote_for_push, get_remotes, push::AsyncProgress,
-	tags::PushTagsProgress,
+	add_remote, delete_remote, get_default_remote,
+	get_default_remote_for_fetch, get_default_remote_for_push,
+	get_remote_url, get_remotes, push::AsyncProgress, rename_remote,
+	tags::PushTagsProgress, update_remote_url, validate_remote_name,
 };
 pub(crate) use repository::repo;
 pub use repository::{RepoPath, RepoPathRef};
@@ -109,8 +110,9 @@ pub use utils::{
 
 pub use git2::ResetType;
 
+/// test utils
 #[cfg(test)]
-mod tests {
+pub mod tests {
 	use super::{
 		commit,
 		repository::repo,
@@ -124,104 +126,6 @@ mod tests {
 	use std::{path::Path, process::Command};
 	use tempfile::TempDir;
 
-	/// Calling `set_search_path` with an empty directory makes sure that there
-	/// is no git config interfering with our tests (for example user-local
-	/// `.gitconfig`).
-	#[allow(unsafe_code)]
-	fn sandbox_config_files() {
-		use git2::{opts::set_search_path, ConfigLevel};
-		use std::sync::Once;
-
-		static INIT: Once = Once::new();
-
-		// Adapted from https://github.com/rust-lang/cargo/pull/9035
-		INIT.call_once(|| unsafe {
-			let temp_dir = TempDir::new().unwrap();
-			let path = temp_dir.path();
-
-			set_search_path(ConfigLevel::System, path).unwrap();
-			set_search_path(ConfigLevel::Global, path).unwrap();
-			set_search_path(ConfigLevel::XDG, path).unwrap();
-			set_search_path(ConfigLevel::ProgramData, path).unwrap();
-		});
-	}
-
-	/// write, stage and commit a file
-	pub fn write_commit_file(
-		repo: &Repository,
-		file: &str,
-		content: &str,
-		commit_name: &str,
-	) -> CommitId {
-		repo_write_file(repo, file, content).unwrap();
-
-		stage_add_file(
-			&repo.workdir().unwrap().to_str().unwrap().into(),
-			Path::new(file),
-		)
-		.unwrap();
-
-		commit(
-			&repo.workdir().unwrap().to_str().unwrap().into(),
-			commit_name,
-		)
-		.unwrap()
-	}
-
-	/// write, stage and commit a file giving the commit a specific timestamp
-	pub fn write_commit_file_at(
-		repo: &Repository,
-		file: &str,
-		content: &str,
-		commit_name: &str,
-		time: git2::Time,
-	) -> CommitId {
-		repo_write_file(repo, file, content).unwrap();
-
-		let path: &RepoPath =
-			&repo.workdir().unwrap().to_str().unwrap().into();
-
-		stage_add_file(path, Path::new(file)).unwrap();
-
-		commit_at(path, commit_name, time)
-	}
-
-	fn commit_at(
-		repo_path: &RepoPath,
-		msg: &str,
-		time: git2::Time,
-	) -> CommitId {
-		let repo = repo(repo_path).unwrap();
-
-		let signature =
-			git2::Signature::new("name", "email", &time).unwrap();
-		let mut index = repo.index().unwrap();
-		let tree_id = index.write_tree().unwrap();
-		let tree = repo.find_tree(tree_id).unwrap();
-
-		let parents = if let Ok(id) = get_head_repo(&repo) {
-			vec![repo.find_commit(id.into()).unwrap()]
-		} else {
-			Vec::new()
-		};
-
-		let parents = parents.iter().collect::<Vec<_>>();
-
-		let commit = repo
-			.commit(
-				Some("HEAD"),
-				&signature,
-				&signature,
-				msg,
-				&tree,
-				parents.as_slice(),
-			)
-			.unwrap()
-			.into();
-
-		commit
-	}
-
 	///
 	pub fn repo_init_empty() -> Result<(TempDir, Repository)> {
 		init_log();
@@ -285,21 +189,44 @@ mod tests {
 		Ok((td, repo))
 	}
 
-	// init log
-	fn init_log() {
-		let _ = env_logger::builder()
-			.is_test(true)
-			.filter_level(log::LevelFilter::Trace)
-			.try_init();
+	/// write, stage and commit a file
+	pub fn write_commit_file(
+		repo: &Repository,
+		file: &str,
+		content: &str,
+		commit_name: &str,
+	) -> CommitId {
+		repo_write_file(repo, file, content).unwrap();
+
+		stage_add_file(
+			&repo.workdir().unwrap().to_str().unwrap().into(),
+			Path::new(file),
+		)
+		.unwrap();
+
+		commit(
+			&repo.workdir().unwrap().to_str().unwrap().into(),
+			commit_name,
+		)
+		.unwrap()
 	}
 
-	/// Same as `repo_init`, but the repo is a bare repo (--bare)
-	pub fn repo_init_bare() -> Result<(TempDir, Repository)> {
-		init_log();
+	/// write, stage and commit a file giving the commit a specific timestamp
+	pub fn write_commit_file_at(
+		repo: &Repository,
+		file: &str,
+		content: &str,
+		commit_name: &str,
+		time: git2::Time,
+	) -> CommitId {
+		repo_write_file(repo, file, content).unwrap();
 
-		let tmp_repo_dir = TempDir::new()?;
-		let bare_repo = Repository::init_bare(tmp_repo_dir.path())?;
-		Ok((tmp_repo_dir, bare_repo))
+		let path: &RepoPath =
+			&repo.workdir().unwrap().to_str().unwrap().into();
+
+		stage_add_file(path, Path::new(file)).unwrap();
+
+		commit_at(path, commit_name, time)
 	}
 
 	/// helper returning amount of files with changes in the (wd,stage)
@@ -334,6 +261,81 @@ mod tests {
 		commit_ids
 	}
 
+	/// Same as `repo_init`, but the repo is a bare repo (--bare)
+	pub fn repo_init_bare() -> Result<(TempDir, Repository)> {
+		init_log();
+
+		let tmp_repo_dir = TempDir::new()?;
+		let bare_repo = Repository::init_bare(tmp_repo_dir.path())?;
+		Ok((tmp_repo_dir, bare_repo))
+	}
+
+	/// Calling `set_search_path` with an empty directory makes sure that there
+	/// is no git config interfering with our tests (for example user-local
+	/// `.gitconfig`).
+	#[allow(unsafe_code)]
+	fn sandbox_config_files() {
+		use git2::{opts::set_search_path, ConfigLevel};
+		use std::sync::Once;
+
+		static INIT: Once = Once::new();
+
+		// Adapted from https://github.com/rust-lang/cargo/pull/9035
+		INIT.call_once(|| unsafe {
+			let temp_dir = TempDir::new().unwrap();
+			let path = temp_dir.path();
+
+			set_search_path(ConfigLevel::System, path).unwrap();
+			set_search_path(ConfigLevel::Global, path).unwrap();
+			set_search_path(ConfigLevel::XDG, path).unwrap();
+			set_search_path(ConfigLevel::ProgramData, path).unwrap();
+		});
+	}
+
+	fn commit_at(
+		repo_path: &RepoPath,
+		msg: &str,
+		time: git2::Time,
+	) -> CommitId {
+		let repo = repo(repo_path).unwrap();
+
+		let signature =
+			git2::Signature::new("name", "email", &time).unwrap();
+		let mut index = repo.index().unwrap();
+		let tree_id = index.write_tree().unwrap();
+		let tree = repo.find_tree(tree_id).unwrap();
+
+		let parents = if let Ok(id) = get_head_repo(&repo) {
+			vec![repo.find_commit(id.into()).unwrap()]
+		} else {
+			Vec::new()
+		};
+
+		let parents = parents.iter().collect::<Vec<_>>();
+
+		let commit = repo
+			.commit(
+				Some("HEAD"),
+				&signature,
+				&signature,
+				msg,
+				&tree,
+				parents.as_slice(),
+			)
+			.unwrap()
+			.into();
+
+		commit
+	}
+
+	// init log
+	fn init_log() {
+		let _ = env_logger::builder()
+			.is_test(true)
+			.filter_level(log::LevelFilter::Trace)
+			.try_init();
+	}
+
 	fn debug_cmd(path: &RepoPath, cmd: &str) -> String {
 		let output = if cfg!(target_os = "windows") {
 			Command::new("cmd")
