@@ -51,7 +51,7 @@ impl From<&str> for RepoPath {
 pub fn repo(repo_path: &RepoPath) -> Result<Repository> {
 	let repo = Repository::open_ext(
 		repo_path.gitpath(),
-		RepositoryOpenFlags::empty(),
+		RepositoryOpenFlags::FROM_ENV,
 		Vec::<&Path>::new(),
 	)?;
 
