@@ -48,8 +48,8 @@ fn sort_file_list(files: &mut [TreeFile]) {
 
 // applies topologically order on paths sorting
 fn path_cmp(a: &Path, b: &Path) -> Ordering {
-	let mut comp_a = a.components().into_iter().peekable();
-	let mut comp_b = b.components().into_iter().peekable();
+	let mut comp_a = a.components().peekable();
+	let mut comp_b = b.components().peekable();
 
 	loop {
 		let a = comp_a.next();
@@ -156,7 +156,7 @@ mod tests {
 
 	#[test]
 	fn test_sorting() {
-		let mut list = vec!["file", "folder/file", "folder/afile"]
+		let mut list = ["file", "folder/file", "folder/afile"]
 			.iter()
 			.map(|f| TreeFile {
 				path: PathBuf::from(f),
@@ -181,7 +181,7 @@ mod tests {
 
 	#[test]
 	fn test_sorting_folders() {
-		let mut list = vec!["bfolder/file", "afolder/file"]
+		let mut list = ["bfolder/file", "afolder/file"]
 			.iter()
 			.map(|f| TreeFile {
 				path: PathBuf::from(f),
@@ -205,7 +205,7 @@ mod tests {
 
 	#[test]
 	fn test_sorting_folders2() {
-		let mut list = vec!["bfolder/sub/file", "afolder/file"]
+		let mut list = ["bfolder/sub/file", "afolder/file"]
 			.iter()
 			.map(|f| TreeFile {
 				path: PathBuf::from(f),
