@@ -81,7 +81,7 @@ impl RevisionFilesComponent {
 		self.show()?;
 
 		let same_id =
-			self.revision.as_ref().map_or(false, |c| c.id == commit);
+			self.revision.as_ref().is_some_and(|c| c.id == commit);
 
 		if !same_id {
 			self.files = None;
@@ -187,7 +187,7 @@ impl RevisionFilesComponent {
 	}
 
 	fn blame(&self) -> bool {
-		self.selected_file_path().map_or(false, |path| {
+		self.selected_file_path().is_some_and(|path| {
 			self.queue.push(InternalEvent::OpenPopup(
 				StackablePopupOpen::BlameFile(BlameFileOpen {
 					file_path: path,
@@ -201,7 +201,7 @@ impl RevisionFilesComponent {
 	}
 
 	fn file_history(&self) -> bool {
-		self.selected_file_path().map_or(false, |path| {
+		self.selected_file_path().is_some_and(|path| {
 			self.queue.push(InternalEvent::OpenPopup(
 				StackablePopupOpen::FileRevlog(FileRevOpen::new(
 					path,
@@ -370,7 +370,7 @@ impl RevisionFilesComponent {
 		Ok(title)
 	}
 
-	fn request_files(&mut self, commit: CommitId) {
+	fn request_files(&self, commit: CommitId) {
 		self.async_treefiles.spawn(AsyncTreeFilesJob::new(
 			self.repo.borrow().clone(),
 			commit,
