@@ -35,7 +35,7 @@ impl From<&GituiKeyEvent> for KeyEvent {
 }
 
 #[derive(Debug, Clone, Patch)]
-#[patch_derive(Deserialize, Debug)]
+#[patch(attribute(derive(Deserialize, Debug)))]
 pub struct KeysList {
 	pub tab_status: GituiKeyEvent,
 	pub tab_log: GituiKeyEvent,
@@ -118,6 +118,11 @@ pub struct KeysList {
 	pub stage_unstage_item: GituiKeyEvent,
 	pub tag_annotate: GituiKeyEvent,
 	pub view_submodules: GituiKeyEvent,
+	pub view_remotes: GituiKeyEvent,
+	pub update_remote_name: GituiKeyEvent,
+	pub update_remote_url: GituiKeyEvent,
+	pub add_remote: GituiKeyEvent,
+	pub delete_remote: GituiKeyEvent,
 	pub view_submodule_parent: GituiKeyEvent,
 	pub update_submodule: GituiKeyEvent,
 	pub commit_history_next: GituiKeyEvent,
@@ -210,6 +215,11 @@ impl Default for KeysList {
 			stage_unstage_item: GituiKeyEvent::new(KeyCode::Enter,  KeyModifiers::empty()),
 			tag_annotate: GituiKeyEvent::new(KeyCode::Char('a'),  KeyModifiers::CONTROL),
 			view_submodules: GituiKeyEvent::new(KeyCode::Char('S'),  KeyModifiers::SHIFT),
+			view_remotes: GituiKeyEvent::new(KeyCode::Char('r'), KeyModifiers::CONTROL),
+			update_remote_name: GituiKeyEvent::new(KeyCode::Char('n'),KeyModifiers::NONE),
+			update_remote_url: GituiKeyEvent::new(KeyCode::Char('u'),KeyModifiers::NONE),
+			add_remote: GituiKeyEvent::new(KeyCode::Char('a'), KeyModifiers::NONE),
+			delete_remote: GituiKeyEvent::new(KeyCode::Char('r'), KeyModifiers::NONE),
 			view_submodule_parent: GituiKeyEvent::new(KeyCode::Char('p'),  KeyModifiers::empty()),
 			update_submodule: GituiKeyEvent::new(KeyCode::Char('u'),  KeyModifiers::empty()),
 			commit_history_next: GituiKeyEvent::new(KeyCode::Char('n'),  KeyModifiers::CONTROL),
