@@ -30,6 +30,8 @@ pub static PUSH_TAGS_STATES_PUSHING: &str = "pushing";
 pub static PUSH_TAGS_STATES_DONE: &str = "done";
 
 pub static POPUP_TITLE_SUBMODULES: &str = "Submodules";
+pub static POPUP_TITLE_REMOTES: &str = "Remotes";
+pub static POPUP_SUBTITLE_REMOTES: &str = "Details";
 pub static POPUP_TITLE_FUZZY_FIND: &str = "Fuzzy Finder";
 pub static POPUP_TITLE_LOG_SEARCH: &str = "Search";
 
@@ -251,6 +253,17 @@ pub fn confirm_title_delete_remote_branch(
 ) -> String {
 	"Delete Remote Branch".to_string()
 }
+pub fn confirm_title_delete_remote(
+	_key_config: &SharedKeyConfig,
+) -> String {
+	"Delete Remote".to_string()
+}
+pub fn confirm_msg_delete_remote(
+	_key_config: &SharedKeyConfig,
+	remote_name: &str,
+) -> String {
+	format!("Confirm deleting remote \"{remote_name}\"")
+}
 pub fn confirm_msg_delete_remote_branch(
 	_key_config: &SharedKeyConfig,
 	branch_ref: &str,
@@ -339,6 +352,49 @@ pub fn create_branch_popup_msg(
 ) -> String {
 	"type branch name".to_string()
 }
+pub fn rename_remote_popup_title(
+	_key_config: &SharedKeyConfig,
+) -> String {
+	"Rename remote".to_string()
+}
+pub fn rename_remote_popup_msg(
+	_key_config: &SharedKeyConfig,
+) -> String {
+	"new remote name".to_string()
+}
+pub fn update_remote_url_popup_title(
+	_key_config: &SharedKeyConfig,
+) -> String {
+	"Update url".to_string()
+}
+pub fn update_remote_url_popup_msg(
+	_key_config: &SharedKeyConfig,
+) -> String {
+	"new remote url".to_string()
+}
+pub fn create_remote_popup_title_name(
+	_key_config: &SharedKeyConfig,
+) -> String {
+	"Remote name".to_string()
+}
+pub fn create_remote_popup_title_url(
+	_key_config: &SharedKeyConfig,
+) -> String {
+	"Remote url".to_string()
+}
+pub fn create_remote_popup_msg_name(
+	_key_config: &SharedKeyConfig,
+) -> String {
+	"type remote name".to_string()
+}
+pub fn create_remote_popup_msg_url(
+	_key_config: &SharedKeyConfig,
+) -> String {
+	"type remote url".to_string()
+}
+pub const fn remote_name_invalid() -> &'static str {
+	"[invalid name]"
+}
 pub fn username_popup_title(_key_config: &SharedKeyConfig) -> String {
 	"Username".to_string()
 }
@@ -830,6 +886,99 @@ pub mod commands {
 		)
 	}
 
+	pub fn view_remotes(key_config: &SharedKeyConfig) -> CommandText {
+		CommandText::new(
+			format!(
+				"Remotes [{}]",
+				key_config.get_hint(key_config.keys.view_remotes)
+			),
+			"open remotes view",
+			CMD_GROUP_GENERAL,
+		)
+	}
+
+	pub fn update_remote_name(
+		key_config: &SharedKeyConfig,
+	) -> CommandText {
+		CommandText::new(
+			format!(
+				"Edit name [{}]",
+				key_config
+					.get_hint(key_config.keys.update_remote_name)
+			),
+			"updates a remote name",
+			CMD_GROUP_GENERAL,
+		)
+	}
+
+	pub fn update_remote_url(
+		key_config: &SharedKeyConfig,
+	) -> CommandText {
+		CommandText::new(
+			format!(
+				"Edit url [{}]",
+				key_config
+					.get_hint(key_config.keys.update_remote_url)
+			),
+			"updates a remote url",
+			CMD_GROUP_GENERAL,
+		)
+	}
+
+	pub fn create_remote(
+		key_config: &SharedKeyConfig,
+	) -> CommandText {
+		CommandText::new(
+			format!(
+				"Add [{}]",
+				key_config.get_hint(key_config.keys.add_remote)
+			),
+			"creates a new remote",
+			CMD_GROUP_GENERAL,
+		)
+	}
+
+	pub fn delete_remote_popup(
+		key_config: &SharedKeyConfig,
+	) -> CommandText {
+		CommandText::new(
+			format!(
+				"Remove [{}]",
+				key_config.get_hint(key_config.keys.delete_remote),
+			),
+			"remove a remote",
+			CMD_GROUP_BRANCHES,
+		)
+	}
+
+	pub fn remote_confirm_name_msg(
+		key_config: &SharedKeyConfig,
+	) -> CommandText {
+		CommandText::new(
+			format!(
+				"Confirm name [{}]",
+				key_config.get_hint(key_config.keys.enter),
+			),
+			"confirm remote name",
+			CMD_GROUP_BRANCHES,
+		)
+		.hide_help()
+	}
+
+	pub fn remote_confirm_url_msg(
+		key_config: &SharedKeyConfig,
+	) -> CommandText {
+		CommandText::new(
+			format!(
+				"Confirm url [{}]",
+				key_config.get_hint(key_config.keys.enter),
+			),
+			"confirm remote url",
+			CMD_GROUP_BRANCHES,
+		)
+		.hide_help()
+	}
+
 	pub fn open_submodule(
 		key_config: &SharedKeyConfig,
 	) -> CommandText {
