@@ -1,5 +1,6 @@
 use crate::{
 	accessors,
+	app::Environment,
 	components::{
 		command_pump, event_pump, visibility_blocking,
 		CommandBlocking, CommandInfo, Component, DrawableComponent,
@@ -15,7 +16,6 @@ use asyncgit::{
 	sync::{self, status::StatusType, RepoPathRef},
 	AsyncGitNotification, AsyncStatus, StatusParams,
 };
-use crossbeam_channel::Sender;
 use crossterm::event::Event;
 use ratatui::{
 	layout::{Alignment, Constraint, Direction, Layout},
@@ -45,39 +45,31 @@ impl Stashing {
 	accessors!(self, [index]);
 
 	///
-	pub fn new(
-		repo: &RepoPathRef,
-		sender: &Sender<AsyncGitNotification>,
-		queue: &Queue,
-		theme: SharedTheme,
-		key_config: SharedKeyConfig,
-	) -> Self {
+	pub fn new(env: &Environment) -> Self {
 		Self {
-			repo: repo.clone(),
+			repo: env.repo.clone(),
 			index: StatusTreeComponent::new(
-				&strings::stashing_files_title(&key_config),
+				env,
+				&strings::stashing_files_title(&env.key_config),
 				true,
-				Some(queue.clone()),
-				theme.clone(),
-				key_config.clone(),
 			),
 			visible: false,
 			options: StashingOptions {
 				keep_index: false,
 				stash_untracked: true,
 			},
-			theme,
+			theme: env.theme.clone(),
 			git_status: AsyncStatus::new(
-				repo.borrow().clone(),
-				sender.clone(),
+				env.repo.borrow().clone(),
+				env.sender_git.clone(),
 			),
-			queue: queue.clone(),
-			key_config,
+			queue: env.queue.clone(),
+			key_config: env.key_config.clone(),
 		}
 	}
 
 	///
-	pub fn update(&mut self) -> Result<()> {
+	pub fn update(&self) -> Result<()> {
 		if self.is_visible() {
 			self.git_status
 				//TODO: support options
@@ -99,6 +91,7 @@ impl Stashing {
 	) -> Result<()> {
 		if self.is_visible() && ev == AsyncGitNotification::Status {
 			let status = self.git_status.last()?;
+			self.index.show()?;
 			self.index.update(&status.items)?;
 		}
 
@@ -140,9 +133,9 @@ impl Stashing {
 }
 
 impl DrawableComponent for Stashing {
-	fn draw<B: ratatui::backend::Backend>(
+	fn draw(
 		&self,
-		f: &mut ratatui::Frame<B>,
+		f: &mut ratatui::Frame,
 		rect: ratatui::layout::Rect,
 	) -> Result<()> {
 		let chunks = Layout::default()
